#
# spec file for package ghc-megaparsec
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name megaparsec
%global pkgver %{pkg_name}-%{version}
Name:           ghc-%{pkg_name}
Version:        9.3.1
Release:        1.6
Summary:        Monadic parser combinators
License:        BSD-2-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-case-insensitive-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-deepseq-prof
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-mtl-prof
BuildRequires:  ghc-parser-combinators-devel
BuildRequires:  ghc-parser-combinators-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-scientific-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
BuildRequires:  ghc-transformers-devel
BuildRequires:  ghc-transformers-prof
ExcludeArch:    %{ix86}

%description
This is an industrial-strength monadic parser combinator library.
Megaparsec is a feature-rich package that tries to find a nice balance between
speed, flexibility, and quality of parse errors.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE.md

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE.md

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Thu May 18 2023 Peter Simons <psimons@suse.com>
- Update megaparsec to version 9.3.1.
  [#]# Megaparsec 9.3.1
  * Fixed a bug related to processing of tabs when error messages are
    rendered. [Issue 524](https://github.com/mrkkrp/megaparsec/issues/524).
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Sun Nov 27 2022 Peter Simons <psimons@suse.com>
- Update megaparsec to version 9.3.0.
  [#]# Megaparsec 9.3.0
  * Now `label` can override more than one group of hints in the parser it
    wraps. [Issue 482](https://github.com/mrkkrp/megaparsec/issues/482).
  * `takeP n` now returns the empty chunk of the input stream when `n` is
    negative, similar to when `n == 0`. [Issue
    497](https://github.com/mrkkrp/megaparsec/issues/497).
  * Added the `MonadParsecDbg` type class in `Text.Megaparsec.Debug`. The type
    class allows us to use `dbg` in MTL monad transformers. [Issue
    488](https://github.com/mrkkrp/megaparsec/issues/488).
  * Introduced the `ShareInput` and `NoShareInput` newtype wrappers in
    `Text.Megaparsec.Stream` in order to allow the user to choose how the
    input should be sliced and shared during the parsing. [Issue
    492](https://github.com/mrkkrp/megaparsec/issues/492).
  [#]# Megaparsec 9.2.2
  * Fixed a space leak in the implementations of the `reachOffset` and
    `reachOffsetNoLine` methods of `TraversableStream`. [Issue
    486](https://github.com/mrkkrp/megaparsec/issues/486).
* Tue Aug 16 2022 Peter Simons <psimons@suse.com>
- Update megaparsec to version 9.2.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon May  9 2022 Peter Simons <psimons@suse.com>
- Update megaparsec to version 9.2.1.
  * Megaparsec follows [SemVer](https://semver.org/).*
  [#]# Megaparsec 9.2.1
  * Builds with `mtl-2.3` and `transformers-0.6`.
* Thu Dec 30 2021 Peter Simons <psimons@suse.com>
- Update megaparsec to version 9.2.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Mon Sep 27 2021 psimons@suse.com
- Update megaparsec to version 9.2.0.
  [#]# Megaparsec 9.2.0
  * Added parsers for binary representations (little/big endian) of numbers in
    `Text.Megaparsec.Byte.Binary`.
* Sun Aug  8 2021 psimons@suse.com
- Update megaparsec to version 9.1.0 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Thu Jul 15 2021 psimons@suse.com
- Update megaparsec to version 9.1.0.
  [#]# Megaparsec 9.1.0
  * Added `dbg'` in `Text.Megaparsec.Debug` for debugging parsers that have
    unshowable return values.
  * Documentation improvements.
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Thu Dec 17 2020 psimons@suse.com
- Update megaparsec to version 9.0.1 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Oct 30 2020 psimons@suse.com
- Update megaparsec to version 9.0.1.
  [#]# Megaparsec 9.0.1
  * Added [Safe
    Haskell](https://downloads.haskell.org/~ghc/latest/docs/html/users_guide/safe_haskell.html)
    support.
* Sat Sep 12 2020 psimons@suse.com
- Update megaparsec to version 9.0.0.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/megaparsec-9.0.0/src/CHANGELOG.md
* Tue Aug 18 2020 Peter Simons <psimons@suse.com>
- Replace %%setup -q with the more modern %%autosetup macro.
* Tue Jun  9 2020 psimons@suse.com
- Add megaparsec at version 8.0.0.
